#
# spec file for package armagetron
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define series 0.2.9
%define src_name %{name}ad
Name:           armagetron
Version:        %{series}.2.3
Release:        2.5
Summary:        OpenGL Game Similar to the Film Tron
License:        GPL-2.0-or-later
Group:          Amusements/Games/Action/Arcade
URL:            https://www.armagetronad.org
Source0:        https://launchpad.net/%{src_name}/%{series}/%{version}/+download/%{src_name}-%{version}.tbz
Patch0:         armagetron-desktop-files-installdir.patch
# PATCH-FIX-UPSTREAM: https://gitlab.com/armagetronad/armagetronad/-/merge_requests/162
Patch1:         reproducible.patch
BuildRequires:  gcc-c++
BuildRequires:  libSDL_image-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  llvm-clang
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(glu)
Requires(post): coreutils

%description
In this game, race against other players on a permanently moving
lightcycle (virtual motorbike), which leaves a wall as a trace. The
lightcycles can make 90 degree turns and accelerate when driven close
to walls. The game is over if you hit a wall. The goal of the game is
to try to make your enemies hit the walls, while you avoid doing the
same. Unlike glTron, this program does not require 3D hardware support.

%prep
%autosetup -p1 -n armagetronad-%{version}

%build
autoreconf -fvi
# clang does not support lto yet
%define _lto_cflags %{nil}
tmpflags="%{optflags} -fPIE -pie"
export CC=clang
export CXX=clang++
# bypass boo#927268 for PowerPC clang
%ifarch ppc64 ppc64le
tmpflags=${tmpflags/-fstack-protector-strong}
%endif
%configure \
	--enable-music \
	--enable-glout \
	--disable-desktop \
	--disable-uninstall \
	--disable-dependency-tracking \
	--disable-games \
	--docdir=%{_docdir} \
	CXXFLAGS="${tmpflags}"
%make_build

%install
# the uninstall_location trick was copied from Fedora. Thanks for debugging it :)
%make_install uninstall_location=foobar
# some cleanups
rm %{buildroot}%{_sysconfdir}/armagetronad/rc.config
rm %{buildroot}%{_sysconfdir}/armagetronad/settings_dedicated.cfg
rm %{buildroot}%{_datadir}/armagetronad/scripts/relocate
rm %{buildroot}%{_bindir}/armagetronad-master
mv %{buildroot}%{_docdir}/armagetronad ./armagetron_doc
chmod -x %{buildroot}%{_datadir}/armagetronad/scripts/rcd_*
%suse_update_desktop_file armagetronad Game ArcadeGame

%files
%license COPYING
%doc README armagetron_doc/*
%config %{_sysconfdir}/armagetronad
%{_bindir}/armagetronad
%{_datadir}/armagetronad/
%{_datadir}/metainfo/armagetronad.appdata.xml
%{_datadir}/applications/*
%{_datadir}/pixmaps/*.png

%post
if [ ! -e %{_datadir}/armagetron/music/fire.xm ]; then
    if [ -r %{_datadir}/gltron/music/song_revenge_of_cats.it ]; then
	cp -a %{_datadir}/gltron/music/song_revenge_of_cats.it \
		%{_datadir}/armagetron/music/fire.xm
    fi
fi

%changelog
* Wed Jul 17 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Fri Apr  5 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.2.9.2.3
  * Fixed Bugs
  - Sound trouble deja entendu (#130)
  - Docker/Alpine: Crash in ZThread::ThreadOps::setPriority
    (#138)
  - Display lists keep rim wall lowered (#141)
  - FPS display inaccurate (#143)
  - Online play suddenly stopped working. (#145)
  - Work around Ubuntu sending spurious window activation
    messages (#68)
  - Desktop/AppData/Icon files are installed in a wrong place
    during make install (#73)
  - Steam: No logging, does not work in pressure vessel (#77)
  - Retina display not working correctly (#88)
  - 0.2.9 clients lose connection on 0.4 server (#98)
  - Window title sometimes SDL_APP (#102)
  - Client sends quickly typed chat message with last character
    missing (#106)
  - Backslashes not escaped when saving to user.cfg (#110)
  - Fix invulnerability bug handling (#111)
  - error: use of undeclared identifier ‘finite’; did you mean
    ‘isfinite’? (#120)
  - User data saved in the wrong place on macOS (#125)
  * New Features
  - Make network trafic realtime priority (#137)
  - Add AppImage zsync update data (#78)
  - Provide docker image for the dedicated server (#79)
  - Add macOS dmg bundling (#86)
  - Integrate macOS build into pipeline (#87)
  - Sign the application bundle (#89)
- Drop reproducible.patch: no longer needed for series 0.2.9.
- Add armagetron-desktop-files-installdir.patch: Fix install dirs
  of desktop file, icon, and metainfo to standard locations.
- Drop armagetron_add.tar.bz2: custom desktop integration files
  and default configs are installed by upstream source.
- Use full URL for source.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Fri Mar 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.2.8.3.5. No changelog.
- Drop fix-segv.patch. Merged upstream.
* Wed Jul 24 2019 Luigi Baldoni <aloisio@gmx.com>
- Disable LTO to fix Factory build
- Enable PIE
- Spec cleanup
* Sat Apr  7 2018 wbauer@tmo.at
- Update to version 0.2.8.3.4:
  * Two issues that surfaced when compiling with gcc 6 were fixed
- Drop armagetron-fix-build.patch, merged upstream
* Sat May  6 2017 meissner@suse.com
- armagetron-fix-build.patch: do not integer compare a pointer against an integer
* Sat May  6 2017 meissner@suse.com
- renamed: armagetron_add.tar.gz -> armagetron_add.tar.bz2
* Thu Oct  6 2016 kieltux@gmail.com
- Some cleanup:
  * removed BuildRequires: kdelibs3-devel (fixes build for
    openSUSE Leap 42.1 and Leap 42.2).
  * added some BuildRequires.
* Thu Aug  4 2016 normand@linux.vnet.ibm.com
- bypass boo#927268 for PowerPC clang failing if fstack-protector
* Wed Jun 29 2016 jengelh@inai.de
- Replace ancient package names
* Tue Jun 28 2016 rpm@fthiessen.de
- Fixed build on Tumbleweed
- Some cleanup
- Added fix-segv.patch to fix segfault after starting a new game
* Wed Apr  6 2016 bwiedemann@suse.com
- Add reproducible.patch to fix build-compare
* Sun Mar 29 2015 dimstar@opensuse.org
- Update to version 0.2.8.3.3:
  + security fix: do not read ahead of the beginning of network
    buffer.
  + security fix: don't attribute network errors from processing
    random packets to the connection to the server.
  + security fix: while at it, don't process random packets unless
    they may be important.
  + fix for potential crash with friend list filtering.
  + intel driver compatibility.
  + fix for rare crash with sound lock.
  + fix for camera turning for bizarre axis configurations.
- Install appdata.xml in order to be shown in AppStream based
  software centers.
- Drop armagetron-configure.patch: fixed upstream.
* Tue Mar 17 2015 dimstar@opensuse.org
- Change the file system layout: have the icon in /usr/share/pixmap
  as being the REAL file instead of being the symlink. This works
  around a current flaw in appstream-builder, which does not follow
  symlinks when extracting/finding icons.
* Tue Sep 18 2012 coolo@suse.com
- add explicit buildrequire for pkgconfig(glu)
* Thu Mar 15 2012 dimstar@opensuse.org
- Update to version 0.2.8.3.2:
  + Various security and bug fixes
  + For a full list of changes see NEWS file.
- Drop patches that have been fixed upstream:
  + armagetronad-0.2.8.2.1-no_type_punning.patch
  + armagetronad-0.2.8.2.1-string_const.patch
  + armagetronad-missing_headers.patch
  + gcc46_add_default_ctors.patch
- Add armagetron-configure.patch: Change detection of libpng.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Mon May  9 2011 cgiboudeaux@gmx.com
- Add gcc46_add_default_ctors.patch
* Fri Jul 10 2009 prusnak@suse.cz
- /usr/games, /usr/share/games -> /usr/bin, /usr/share
* Mon Jun  8 2009 pth@suse.de
- Rename dominique's patch and make it include cstring not string.h
- use %%{_datadir} instead of /usr/share.
- Backport fixes regarding conversions from string constants to
  char* and type-punning from 0.2.8.3_rc2.
* Fri Jun  5 2009 coolo@novell.com
- fix usage of strchr
* Tue May  5 2009 dominique-obs@leuenberger.net
- Update to version 0.2.8.2.1
- Fix the package to actually work (bnc#331629)
* Fri Oct 26 2007 pth@suse.de
- Add missing includes.
* Mon Jun  4 2007 pth@suse.de
- Move binary files to their correct place.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec  1 2005 pth@suse.de
- Use -fno-strict-aliasing for now as the source is too convoluted.
- Fix uninitialized usage.
- Minor code cleanups
* Tue May 24 2005 yxu@suse.de
- fixed for GCC4
* Thu Apr 14 2005 pth@suse.de
- Update to 0.2.7.1 which obsoletes most patches.
- Modify the autotools configury so that autoreconf can be used.
* Tue Feb 15 2005 lnussel@suse.de
- fixes for DoS bugs found by Luigi Auriemma (#50850)
* Tue Jan 25 2005 uli@suse.de
- update -> 0.2.7.0 ("A. Advanced")
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Sat Aug 30 2003 sndirsch@suse.de
- added desktop icon
* Mon Aug 25 2003 ro@suse.de
- try to fix compilation
* Mon Aug 11 2003 sndirsch@suse.de
- improved desktop category
* Sun Aug 10 2003 sndirsch@suse.de
- install (adjusted) desktop file according to the new policy
* Thu Jun 19 2003 ro@suse.de
- added kdelibs3 to neededforbuild
- added directories to filelist
* Tue Jan 28 2003 ro@suse.de
- fix build with gcc-3.3
* Wed Sep 11 2002 bk@suse.de
- use 20 as initial AI IQ like in software.Armagetronrc, it's easyer
  to begin and they adapt to the player anyway if he is good.
* Tue Sep 10 2002 bk@suse.de
- fix software.Armagetronrc and remove oudated hardware.ArmageTronrc
* Tue Sep 10 2002 bk@suse.de
- fix mode arg of the mkdir for creating the conf dir(bug #18192)
- fix broken installation of cfg files for arrow keys to %%datadir
- improve game fun: limited wall length, four players by default
  and walls that burn down slowly after a half second delay.. :-)
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Wed Jul 31 2002 sf@suse.de
-  added 64-bit fixes
* Tue Jul 23 2002 bk@suse.de
- updated to 0.2.0.pre_020721, pushes performance and fun by factor
* Mon Mar 18 2002 bk@suse.de
- fix menu path to binary in Armagetron.desktop(fix for bug 14987)
- allow menu wrap also in default config(was already in hw-cfg)
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Fri Jan 11 2002 bk@suse.de
- polished the default config, hardware.ArmageTronrc and README.SuSE
- software.ArmageTronrc is obsoleted
* Fri Jan 11 2002 ro@suse.de
- no subdirs in /usr/games
* Fri Nov 16 2001 bk@suse.de
- remove src/engine/test from tarball, saves 150k compressed size
- enable WRAP_MENU in the default Armatetronrc settings files
* Thu Nov  8 2001 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Mon Sep  3 2001 schwab@suse.de
- Fix to compile on ia64.
* Wed Aug  8 2001 ro@suse.de
- changed neededforbuild <kdelibs kdelibs-devel> to <kdelibs-artsd>
* Wed Aug  8 2001 ro@suse.de
- changed neededforbuild <sdl> to <SDL>
- changed neededforbuild <sdl-devel> to <SDL-devel>
* Thu Jul 19 2001 bk@suse.de
- update to 0.1.4.9 which includes some fixes and merges patches
* Tue Jul  3 2001 ro@suse.de
- added kdelibs for artsd
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Mon Mar 26 2001 ro@suse.de
- changed neededforbuild <sdl> to <sdl sdl-devel>
* Thu Mar 15 2001 ro@suse.de
- changed neededforbuild <mesaglu> to <xf86glu>
- changed neededforbuild <mesaglu-devel> to <xf86glu-devel>
* Thu Mar  8 2001 uli@suse.de
- added xf86, mesaglu* to neededforbuild
* Wed Mar  7 2001 ro@suse.de
- changed neededforbuild <mesadev> to <mesa-devel>
* Tue Mar  6 2001 bk@suse.de
- fix installation paths to for FHS compliance, use marcos and wildcards
- improved default.cfg(now 3 AI players and better screenmode, cool!)
- added patch to make manual chdir to datadir obsolete
- added dedicated armagetron-server program
- added man pages for armagetron and armagetron-server
- added README.SuSE
- added config examples (hardware.ArmageTronrc, software.ArmageTronrc)
- packaed all additional source files into armagetron_add.tar.bz2
- removed unneccesary glib and glib-devel from neededforbuild
* Tue Mar  6 2001 bk@suse.de
- initial version
